@@ -9,6 +9,9 @@ multisum <- summary(multi)
 data("nlp", package = "rsimsum")
 nlps <- rsimsum::simsum(data = nlp, estvarname = "b", true = 0, se = "se", methodvar = "model", by = c("baseline", "ss", "esigma"))
 nlpssum <- summary(nlps)
+data("MIsim2", package = "rsimsum")
+multiplemethodvar <- rsimsum::simsum(data = MIsim2, estvarname = "b", true = 0.5, se = "se", methodvar = c("m1", "m2"), x = T)
+multiplemethodvarsum <- summary(multiplemethodvar)
 
 testthat::test_that("output from autoplot is of class gg, ggplot", {
   # simsum object, no 'by'
@@ -78,6 +81,37 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   # nested loop plot
   testthat::expect_s3_class(object = autoplot(nlps, type = "nlp"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(nlpssum, type = "nlp"), class = c("gg", "ggplot"))
+  # multiple columns identifying methods
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "forest"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "lolly"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "zip"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "est"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "se"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "est_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "se_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "est_ridge"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "se_ridge"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvar, type = "heat"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "forest"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "lolly"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "zip"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "est"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "se"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "est_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "se_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "est_ridge"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "se_ridge"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multiplemethodvarsum, type = "heat"), class = c("gg", "ggplot"))
 })
 
 testthat::test_that("argument checks works throws errors when appropriate", {
@@ -169,6 +203,49 @@ testthat::test_that("argument checks works throws errors when appropriate", {
   testthat::expect_error(object = print(autoplot(multisum, density.legend = "Bamboozled")))
   testthat::expect_error(object = print(autoplot(multisum, zoom = TRUE)))
   testthat::expect_error(object = print(autoplot(multisum, zoom = "Why not?")))
+  # multiple columns identifying methods
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, type = "megacool_plot")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, type = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, type = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, stats = "summary")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, stats = "BIAS")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, stats = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, stats = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, target = "top")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, target = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, fitted = NULL)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, fitted = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, fitted = "yes")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, scales = "both")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, scales = "none")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, scales = "either")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, top = 0)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvar, zoom = "Why not?")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, type = "megacool_plot")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, type = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, type = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, stats = "summary")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, stats = "BIAS")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, stats = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, stats = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, target = "top")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, target = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, fitted = NULL)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, fitted = 1)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, fitted = "yes")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, scales = "both")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, scales = "none")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, scales = "either")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, top = 0)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(multiplemethodvarsum, zoom = "Why not?")))
 })
 
 testthat::test_that("autoplot with target", {
